<?php

/**
 * @file
 * Administrative page callbacks for the List Packages module.
 */

/**
 * Creates a list of database log administration filters that can be applied.
 *
 * @return array
 *   Associative array of filters. The top-level keys are used as the form
 *   element names for the filters, and the values are arrays with the following
 *   elements:
 *   - title: Title of the filter.
 *   - where: The filter condition.
 *   - options: Array of options for the select list for the filter.
 */
function list_packages_filters() {
  $filters = [];

  $filters['if_vulnerability'] = [
    'title' => t('If Vulnerabilities'),
    'where' => "lpip.if_vulnerability = ?",
    'options' => [
      0 => 'No vulnerabilities',
      1 => 'Vulnerabilities',
      2 => 'No Information',
      3 => 'Not Definative',
      4 => 'Internal Scripts',
    ],
  ];

  foreach (_list_packages_get_vendors() as $vendor) {
    $vendors[$vendor] = $vendor;
  }

  if (!empty($vendors)) {
    $filters['vendor'] = [
      'title' => t('Vendor'),
      'where' => "lpip.vendor = ?",
      'options' => $vendors,
    ];
  }

  return $filters;
}

/**
 * Creates a list of database log administration filters that can be applied.
 *
 * @return array
 *   Associative array of filters. The top-level keys are used as the form
 *   element names for the filters, and the values are arrays with the following
 *   elements:
 *   - title: Title of the filter.
 *   - where: The filter condition.
 *   - options: Array of options for the select list for the filter.
 */
function list_libraries_filters() {
  $filters = [];

  $filters['if_vulnerability'] = [
    'title' => t('If Vulnerabilities'),
    'where' => "lpip.if_vulnerability = ?",
    'options' => [
      0 => 'No vulnerabilities',
      1 => 'Vulnerabilities',
      2 => 'No Information',
      3 => 'Not Definative',
      4 => 'Internal Scripts',
    ],
  ];

  $filters['type'] = [
    'title' => t('Type'),
    'where' => "lpip.type = ?",
    'options' => [
      'composer' => 'composer.json',
      'package' => 'package.json',
      'other' => 'other',
    ],
  ];

  return $filters;
}

/**
 * Creates a list of database log administration filters that can be applied.
 *
 * @return array
 *   Associative array of filters. The top-level keys are used as the form
 *   element names for the filters, and the values are arrays with the following
 *   elements:
 *   - title: Title of the filter.
 *   - where: The filter condition.
 *   - options: Array of options for the select list for the filter.
 */
function list_modules_filters() {
  $filters = [];

  $filters['if_vulnerability'] = [
    'title' => t('If Vulnerabilities'),
    'where' => "lpip.if_vulnerability = ?",
    'options' => [
      0 => 'No vulnerabilities',
      1 => 'Vulnerabilities',
      2 => 'No Information',
      3 => 'Not Definative',
      4 => 'Internal Scripts',
    ],
  ];

  $filters['type'] = [
    'title' => t('Type'),
    'where' => "lpip.type = ?",
    'options' => [
      'core-module' => 'Core Module',
      'contrib-module' => 'Contrib Module',
      'custom-module' => 'Custom Module',
      'core-theme' => 'Core Theme',
      'contrib-theme' => 'Contrib Theme',
      'custom-theme' => 'Custom Theme',
    ],
  ];

  return $filters;
}

/**
 * Creates a list of database log administration filters that can be applied.
 *
 * @return array
 *   Associative array of filters. The top-level keys are used as the form
 *   element names for the filters, and the values are arrays with the following
 *   elements:
 *   - title: Title of the filter.
 *   - where: The filter condition.
 *   - options: Array of options for the select list for the filter.
 */
function list_module_libraries_filters() {
  $filters = [];

  foreach (_list_packages_get_module_names() as $name) {
    $modules[$name] = $name;
  }

  if (!empty($modules)) {
    $filters['name'] = [
      'title' => t('Module Name'),
      'where' => "lpim.name = ?",
      'options' => $modules,
    ];
  }

  $filters['if_vulnerability'] = [
    'title' => t('If Vulnerabilities'),
    'where' => "lml.if_vulnerability = ?",
    'options' => [
      0 => 'No vulnerabilities',
      1 => 'Vulnerabilities',
      2 => 'No Information',
      3 => 'Not Definative',
    ],
  ];

  $filters['if_internal'] = [
    'title' => t('If Internal'),
    'where' => "lml.if_internal = ?",
    'options' => [
      0 => 'External',
      1 => 'Internal',
    ],
  ];

  $filters['type'] = [
    'title' => t('Type'),
    'where' => "lml.type = ?",
    'options' => [
      'css' => 'Css',
      'js' => 'Js',
    ],
  ];

  return $filters;
}

/**
 * Creates a list of database log administration filters that can be applied.
 *
 * @return array
 *   Associative array of filters. The top-level keys are used as the form
 *   element names for the filters, and the values are arrays with the following
 *   elements:
 *   - title: Title of the filter.
 *   - where: The filter condition.
 *   - options: Array of options for the select list for the filter.
 */
function list_core_libraries_filters() {
  $filters = [];

  $filters['if_vulnerability'] = [
    'title' => t('If Vulnerabilities'),
    'where' => "lpcl.if_vulnerability = ?",
    'options' => [
      0 => 'No vulnerabilities',
      1 => 'Vulnerabilities',
      2 => 'No Information',
      3 => 'Not Definative',
    ],
  ];

  $filters['type'] = [
    'title' => t('Type'),
    'where' => "lpcl.type = ?",
    'options' => [
      'css' => 'Css',
      'js' => 'Js',
    ],
  ];

  return $filters;
}

/**
 * Sort to objects by a property.
 *
 * @var object $object1
 *  The first object.
 * @var object $object2
 *  The second object.
 *
 * @return string
 *   A value.
 */
function comparator($object1, $object2) {
  return $object1->if_vulnerability <=> $object2->if_vulnerability;
}
