<?php

namespace Drupal\list_packages\Form;

use Drupal\Core\Database\Connection;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirmation form before clearing out the logs.
 *
 * @internal
 */
class ListModulesClearLogConfirmForm extends ConfirmFormBase {
  use BaseTrait;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Constructs a new DblogClearLogConfirmForm.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('database')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'list_packages_module_confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the recent logs?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('list_packages.installed_modules');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->getRequest()->getSession()->remove('list_modules_overview_filter');
    $this->getRequest()->getSession()->remove('list_module_libraries_overview_filter');
    $this->connection->truncate('lp_installed_module')->execute();
    $this->connection->delete('lp_vulnerabilities')
      ->condition('table', $this->databases['lp_installed_module'])
      ->execute();
    $this->connection->truncate('lp_module_library')->execute();
    $this->connection->delete('lp_vulnerabilities')
      ->condition('table', $this->databases['lp_module_library'])
      ->execute();
    $this->connection->update('lp_dashboard')
      ->fields(
      [
        'modules_report' => "",
        'themes_report' => "",
        'modsthems_ext_css_libraries_report' => "",
        'modsthems_ext_js_libraries_report' => "",
      ]
    )->execute();
    $this->messenger()->addStatus($this->t('Database log cleared.'));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
