<?php

namespace Drupal\list_packages\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a form that configures forms module settings.
 */
class ListPackagesConfigurationForm extends ConfigFormBase {

  /**
   * The messenger service.
   *
   * @var Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * ConfigurationForm constructor.
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger interface.
   */
  public function __construct(
    MessengerInterface $messenger,
  ) {
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'list_packages_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'list_packages.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('list_packages.settings');

    $form['phpunit'] = [
      '#type' => 'details',
      '#title' => $this->t('Testsuite settings'),
      '#open' => TRUE,
    ];

    $form['phpunit']['testsuite_if_composer'] = [
      '#type' => 'radios',
      '#title' => $this->t('If you site uses composer.'),
      '#options' => [
        $this->t('Use installed.json'),
        $this->t('Use composer show -l'),
      ],
      '#default_value' => $config->get('testsuite_if_composer') ? $config->get('testsuite_if_composer') : 0,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (strlen($form_state->getValue('testsuite_if_composer')) > 1) {
      $form_state->setErrorByName(
        'testsuite_if_composer',
        $this->t('Incorrect value submitted.')
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = $this->config('list_packages.settings');
    $settings->set('testsuite_if_composer', $form_state->getValue('testsuite_if_composer'))
      ->save();

    $this->messenger->addStatus('If Composer has been updated.');

    parent::submitForm($form, $form_state);
  }

}
