<?php

namespace Drupal\list_packages;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Http\ClientFactory;
use Drupal\testsuite\BaseFileService;

/**
 * The client for accessing packages.drupal.org.
 */
class GetDrupalClient extends BaseFileService {

  /**
   * The client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $client;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleExtensionList;

  /**
   * CatFactsClient constructor.
   *
   * @param \Drupal\Core\Http\ClientFactory $httpClientFactory
   *   The client factory.
   * @param \Drupal\Core\Extension\ModuleExtensionList $moduleExtensionList
   *   The module handler service.
   */
  public function __construct(
    ClientFactory $httpClientFactory,
    ModuleExtensionList $moduleExtensionList,
  ) {
    $version = $moduleExtensionList->getExtensionInfo('testsuite')['version'];
    $this->client = $httpClientFactory->fromOptions(
      [
        'base_uri' => 'https://packages.drupal.org',
        "headers" => [
          "User-Agent" => "drupal/testsuite v$version",
        ],
      ]
    );
  }

  /**
   * Gets info on a package.
   *
   * @param string $package
   *   The package.
   *
   * @return array
   *   The status and message.
   */
  public function getPackagesDrupalInfo($package) {
    try {
      $response = $this->client->get("/8/search.json?s=$package", []);
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

  /**
   * Gets vulnerabilities on a package.
   *
   * @param string $vendor
   *   The vendor.
   * @param string $package
   *   The package.
   *
   * @return array
   *   The status and message.
   */
  public function getVulnerabilities($vendor, $package) {
    try {
      $response = $this->client->get("/8/security-advisories/?packages[]=$vendor/$package", []);
      $data = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

}
