<?php

namespace Drupal\list_packages;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Http\ClientFactory;
use Drupal\testsuite\BaseFileService;

/**
 * The client for accessing packages.drupal.org.
 */
class GetGithubClient extends BaseFileService {

  /**
   * The client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $client;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleExtensionList;

  /**
   * CatFactsClient constructor.
   *
   * @param \Drupal\Core\Http\ClientFactory $httpClientFactory
   *   The client factory.
   * @param \Drupal\Core\Extension\ModuleExtensionList $moduleExtensionList
   *   The module handler service.
   */
  public function __construct(
    ClientFactory $httpClientFactory,
    ModuleExtensionList $moduleExtensionList,
  ) {
    $version = $moduleExtensionList->getExtensionInfo('testsuite')['version'];
    $this->client = $httpClientFactory->fromOptions(
      [
        'base_uri' => 'https://api.github.com/advisories',
        "headers" => [
          "User-Agent" => "drupal/testsuite v$version",
          "Accept" => "application/vnd.github+json",
          "X-GitHub-Api-Version" => "2022-11-28",
        ],
      ]
    );
  }

  /**
   * Gets advisory info.
   *
   * @param string $package
   *   The package name.
   *
   * @return array
   *   The status and message.
   */
  public function getAdvisoryInfo($package) {
    try {
      $response = $this->client->get("?affects={$package}", []);
      $data['message'] = Json::decode($response->getBody());
      $data['status'] = TRUE;
      return $data;
    }
    catch (\Exception $e) {
      return ['status' => FALSE, 'message' => $e->getMessage()];
    }
  }

}
