<?php

namespace Drupal\testsuite\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Returns responses for test reports routes.
 */
class TestSuiteController extends ControllerBase {

  /**
   * Landing page for custom tests.
   *
   * @return array
   *   The page as a render array.
   */
  public function landingPage() {
    $build['phpcs-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => 'phpcs-wrapper',
      ],
    ];

    $build['phpcs-container']['install-coder-and-phpcs-with-composer'] = [
      '#type' => 'markup',
      '#markup' => '<h2>Install Coder and phpcs with Composer</h2><p><b>Follow the directions here:</b> <a href="https://www.drupal.org/docs/contributed-modules/code-review-module/installing-coder" target="_blank">Install Coder and phpcs with Composer</a></p>',
    ];

    $code = '
      <pre>
        <code>
          {
            "editor.insertSpaces": true,
            "editor.formatOnPaste": true,
            "editor.formatOnSave": false,
            "editor.renderFinalNewline": "on",
            "editor.renderWhitespace": "boundary",
            "editor.autoClosingBrackets": "always",
            "editor.wordWrap": "on",
            "editor.wordWrapColumn": 80,
            "editor.rulers": [
              80
            ],
            "files.associations": {
              "*.inc": "php",
              "*.module": "php",
              "*.install": "php",
              "*.theme": "php",
              "*.profile": "php",
              "*.tpl.php": "php",
              "*.test": "php",
              "*.php": "php",
              "*.info": "ini",
            },
            "intelephense.format.braces": "k&r",
            "phpcs.standard": "Drupal,DrupalPractice",
            "files.trimTrailingWhitespace": false,
            "files.insertFinalNewline": true,
            "files.eol": "\n"
          }
        </code>
      </pre>
    ';

    $build['phpcs-container']['configure-vscode-for-phpcs'] = [
      '#type' => 'markup',
      '#markup' => '<h2>Configure VSCode for PHPCs</h2><p>You can install Coder globaly then add phpcs to the path. It makes it easy to use phpcs. Adjusting the settings.json by adding these settings helps VSCode display errors you will need to fix related to PHPCs. To add these settings hit ctrl -> shift -> p and search \'Open User Settings (Json)\' in the search bar. Then add these to the Json string.</p>' . $code . '<p>If you find a fix for the newline after closing brace please let me know. Then we can set editor.formatOnSave to true. 🙂 Thanks</p></p>This assumes you have installed php intelephense and the phpcs extensions in your VSCode. This video explains this in more detail without adjusting for Drupal <a href="https://www.youtube.com/watch?v=MTN8OcD5aZg" target="_blank">PHP CodeSniffer in VSCode Using the phpcs Extension</a>. Here is another short video for dealing with the end of line errors. <a href="https://radu.link/vs-code-fix-end-of-line-character-is-invalid/" target="_blank">VS Code Fix for "End of line character is invalid" PHPCS Error</a>. If git is sending these warnings when you commit <a href="https://stackoverflow.com/questions/17628305/windows-git-warning-lf-will-be-replaced-by-crlf-is-that-warning-tail-backwar" target="_blank">LF will be replaced by CRLF the next time Git touches it</a></p>',
    ];

    $build['security-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => 'security-wrapper',
      ],
    ];

    $build['secure-form-fields-and-route-parameters'] = [
      '#type' => 'markup',
      '#markup' => '<p><b>This is not a full list. Please review <a href="https://www.drupal.org/docs/7/security/writing-secure-code" target="_blank">Writing Secure Code</a> and <a href="https://www.drupal.org/docs/administering-a-drupal-site/security-in-drupal/writing-secure-code-for-drupal" target="_blank">Writing secure code for Drupal</a> for more.</b></p><h3>Sanitize all user-supplied data. Validation is your first line of defense.</h3><p>Input sanitization is the process of making sure that the data is properly formatted, and valid within its context. This ensures that the data is safe and free from any potential harm, such as code injections or other security vulnerabilities. Absolutely do not publish a release until you are sure you are done with all security on your module. Make sure all form fields and parameters that might open up a vulnerability are sanitized. Untrusted data comes from any sources originating from outside your application or created by a user. This includes APIs, folders and user generated names and all of it needs to be checked before its used. Here is a StackOverflow comment on best practices.</p>',
    ];
    $build['object-oriented-programming'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Use OOP (Object-Oriented Programming).</h3><p>Encapsulate data in classes using private methods and properties when ever possible. Use getters and setter to access properties and only use public methods when you have to. Use Inheritance, Traits and Dependency Injection to connect classes and use them in your code. When you can if you need access other than private try to use protected. Try to avoid using static methods and properties when possible. Avoid static calls to \Drupal:: and use DI.</p>',
    ];
    $build['give-extra-care-eval-shellexec'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Give extra care when using shell_exec(), exec(), eval() etc..</h3><p>Methods that execute code are an even bigger security risk. Try to put them in an inherited class in a protected method or in a private method of the calling class and make sure nothing but what you want passes to it gets passed to it. Be carefull to sanitize all parameters that get passed to the calling method. Use escapeshellcmd() and  escapeshellarg() to reduce the risk of errors in code propagating through to exploitable commands.</p>',
    ];
    $build['escape-all-sql-parameters'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Escape all SQL parameters.</h3><p><a href="https://www.drupal.org/docs/7/security/writing-secure-code/database-access" target="_blank">Mysql Injection</a> happens when you fail to escape user-supplied data as a parameter to an raw SQL query.</p>',
    ];
    $build['use-code-checkers'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Use Phpcs and Phpstan.</h3><p>Validate your code with packages like Phpcs and Phpstan. Although alot of the results are related to spacing, line indentation and code beautification, errors in your code get spotted too.</p>',
    ];
    $build['xss-attacks'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Filter database data for <a href="https://www.drupal.org/docs/administering-a-drupal-site/security-in-drupal/writing-secure-code-for-drupal" target="_blank">Xss</a>.</h3><p>When handling data, the golden rule is to store exactly what the user typed. When a user edits a post they created earlier, the form should contain the same things as it did when they first submitted it (including any dangerous content they may have included). This means that conversions are performed when content is output, not when saved to the database (be sure to read the db_query() documentation on how to use the database API securely).</p><p>If you want special formating use Drupal\Component\Utility\Xss::filterAdmin($string) to filter the data when you pull it from the database before you put it on the page. It applies a very permissive XSS/HTML filter for admin-only use and allows all tags that can be used inside an HTML body, save for scripts and styles.</p>',
    ];
    $build['regex'] = [
      '#type' => 'markup',
      '#markup' => '<h3>Filtering with Regex</h3><p>Don\'t forget to add starting string ^ and ending string $ to determine the start and ending of the string you are matching.</p>',
    ];

    return $build;
  }

}
